==> ScriptDeploy-0.1.tar: ScriptDeploy/lang/en_US.php <==
<?php


$lang['friendlyname'] = 'Script Deploy';
$lang['postinstall'] = 'The first stop you\'ll want to make is the help';
$lang['postuninstall'] = 'Please feel free to let us know if there is a way to make ScriptDeploy better, <a href="http://help.corbensproducts.com/make-contact.html">Contact us we\'er happy to hear from you.</a>';
$lang['really_uninstall'] = 'Uninstalling this module will not affect any event data and all books to date will still be there. Do you wish to continue?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';

///Admin
$lang['ACToptions'] = 'Account Options';
$lang['manualassignment'] = 'Assignment';

$lang['Script_list'] = 'Scripts';
$lang['Ass_header'] = 'Unified Scripts';
$lang['SampleTag'] = 'Sample Tag';

$lang['prompt_newScript'] = 'Add New Script';
$lang['prompt_newScriptAss'] = 'Add New Script Assignment';
$lang['title_Groups'] = 'Group of Scripts List';
$lang['title_Scripts'] = 'Single Scripts List';
$lang['areyousure'] = 'Important:\n\nIf this is deleted all information will be lost!\n\nIf you have this script in a group you will break the tie and will need to edit the group.\nIt is best to start the deletion process from the Assignment area.';


$lang['smartyHow'] = 'the smarty works like this... Where you\'d have {$smarty.now} you do :::$smarty.now:::  .  Now you can do smarty stuff';


///messages

$lang['Canceled'] = 'You Canceled out of the operation.  Any Work you may have entered has been lost.';

$lang['BtnADDED'] = 'You Just Added a new Script';
$lang['BtnEDITED'] = 'You Just Edited an existing Script';
$lang['BtnDELETED'] = 'You Just Deleted an existing Script';
$lang['type_label'] = 'Type';

$lang['emtpyGroup'] = "You'll need to add a script to the group before calling it";

//Account options
$lang['ScriptSet_label'] = 'Script ID';
$lang['scriptType_label'] = 'Script Type';
$lang['ScriptName_label'] = 'Script Name';
$lang['SingleCode_label'] = 'Default Single Script Call';
$lang['GrouptSize_label'] = 'Total';




$lang['Minify_label'] = 'Minify';
$lang['maxAge_label'] = 'maxAge';
$lang['CreationDate_label'] = 'Creation Date';
$lang['ModifedDate_label'] = 'Modified Date';
$lang['pathOption_label'] = 'Use a path';
$lang['ScriptIs_label'] = 'Use this script <em>(Note: If a path is set, it will over ride this)</em>';
$lang['debugIT_label'] = 'debugIT';
$lang['debugITnote_label'] = '<em>(Must have Firephp mod)</em>';
$lang['debugT'] = 'Debuging Options';


$lang['noneInType'] = '<h1>You must first add <br/>a script in this type</h1>';


$lang['smartyOn_label'] = '<strong>Process Smarty</strong><br/> data in button fields';
$lang['smartyOn'] = '<h1>Process Smarty data</h1>
<h3>With this turned on you can set the button fields with the values passed by other modules such as Products or Cataloger</h3>';

///Actions
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
//Alerts and Messages
$lang['ClearImg'] = 'Delete Current Image';


$lang['cancel'] = 'Cancel';
$lang['form_cancel'] = 'Cancel';

$lang['done'] = 'Done';
$lang['add'] = 'Add';
$lang['submit'] = 'Submit';
$lang['form_submit'] = 'Save Preferences';

$lang['mod_prefs_title'] = 'Module Preferences';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['optionsupdated'] = 'options updated';





$lang['moddescription'] = 'ScriptDeploy is a PayPal button manager. It handles the buttons internal to the site also lifts the 100 button cap of PayPal hosted buttons. Secure using time based sha1 encryption; Tie to most mods; Fire UTD\'s or plug-ins. Simple, flexible.';
$lang['welcome_text'] = '<p>Hello!</p>';
$lang['changelog'] = '
<ul>

  <li>Version 0.1 Beta release.</li>
</ul>';
$lang['help'] = '<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet"/><div class="SimWrap"><b class="rbottom"><b class="r1"></b> <b class="r2"></b><b class="r3"></b> <b class="r4"></b></b>

<div class="Simcon"> <h3 class="BackLink"><a onclick="javascript:window.history.go(-1)" target="_blank" rel="nofollow">&lt;&lt; Back</a></h3>
<h1>What Does This Do?--- this needs updating</h1>
<h2>Write manage and deploy JS and CSS</h2>
<a id="ScriptDeploy"></a>
<p>ScriptDeploy module that can combine multiple CSS or Javascript files, compress their contents (i.e. removal of unnecessary whitespace/comments), and serve the results with HTTP encoding (gzip/deflate) and headers that allow optimal client-side caching. This helps you follow several of Yahoo!\'s <a href="http://developer.yahoo.com/performance/index.html#rules" target="_blank" rel="nofollow">Rules for High Performance Web Sites</a>. (See &quot;Problem Domain&quot; below for more info.) </p>
<h3>The Short of it</h3>
<p>Wirte your scripts, set the order and ScriptDeploy will do the rest!</p>
<table>
  <tbody>
    <tr>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><strong>Before</strong></td>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><img src="http://mrclay.org/wp-content/uploads/2008/09/fiddler_before.png" alt="after" /></td>
    </tr>
    <tr>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><strong>After</strong></td>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><img src="http://mrclay.org/wp-content/uploads/2008/09/fiddler_after.png" alt="before" /></td>
    </tr>
  </tbody>
</table>



<h2><a id="Features"></a>Features</h2>
<ul>
  <li>Combines and minifies multiple CSS or JavaScript files into a single   download </li>
  <li>Uses an <a href="http://code.google.com/p/minify/source/browse/trunk/min/lib/JSMin.php" target="_blank" rel="nofollow">enhanced port</a> of Douglas Crockford\'s <a href="http://www.crockford.com/javascript/jsmin.html" target="_blank" rel="nofollow">JSMin   library</a> and custom classes to minify <a href="http://code.google.com/p/minify/source/browse/trunk/min/lib/Minify/CSS.php" target="_blank" rel="nofollow">CSS</a> and <a href="http://code.google.com/p/minify/source/browse/trunk/min/lib/Minify/HTML.php" target="_blank" rel="nofollow">HTML</a></li>
  <li>Caches server-side to avoid doing unnecessary work </li>
  <li>Responds with an HTTP 304 (Not Modified) response when the browser has an   up-to-date cache copy ** </li>
  <li>Most modules are lazy-loaded as needed (304 responses use minimal code)  ** </li>
  <li>Automatically rewrites relative URIs in combined CSS files to point to valid locations </li>
  <li>With caching enabled, ScriptDeploy is capable of handling hundreds of requests per second on a moderately powerful server. </li>
  <li>Content-Encoding: gzip, based on request headers. Caching allows it so serve gzipped files faster than Apache\'s mod_deflate option! </li>
</ul>
<h3><em><strong>** Note:</strong> It is best to use a .htaccess script to set the age times. ScriptDeploy is designed for efficiency, but for very high traffic sites, ScriptDeploy may serve files slower than your HTTPd due to the CGI overhead of PHP.  To over come this Just check "use .htaccess in options"</em></h3>
<h2><a name="Requirements"></a>Requirements</h2>
<ul>
  <li>The commonly installed <a href="http://us3.php.net/manual/en/zlib.installation.php" target="_blank" rel="nofollow">zlib   extension</a> is recommended for HTTP encoding functionality. </li>
</ul>
<br/><br/>
<h1>How Do I Use It</h1>


<h3>Get a single script</h3>
use <span class="codeHIGHLIGHT">{cms_module module=ScriptDeploy scriptID="1"} </span> <br/><br/>
<h3>Get a script group</h3>
use <span class="codeHIGHLIGHT">{cms_module module=ScriptDeploy groupID="1"} </span> <br/><br/>
<h2>All output is in the XHTML format, you should work in that.</h2>

<br/><br/>
<h4>Params</h4>
<ul>
<li><strong>scriptID="" </strong><em>(Required/optional)</em> <br/>| set the ID Required only if groupID not called<br/></li>
<li><strong>groupID="" </strong><em>(Required/optional)</em> <br/>| set the ID Required only if scriptID not called<br/></li>
<!--<li><strong>SandBox=true </strong><em>(optional)</em> <br/>| false<br/></li>

<li><strong>RUNaction="" </strong><em>(optional)</em> <br/>| UDT<br/>| URL <em>(../plugins/function.filename.php)</em><br/>| *More coming Soon*<br/></li>
<li><strong>Lang="" </strong><em>(optional)</em> <br/>| Use Country Codes To dynamicly set the language of the PayPal page<br/></li>-->

</ul>
<br/>

<br/><br/>
<h2><a id="Problem_Domain"></a>Problem Domain</h2>
<p>Pages that refer to multiple CSS or JavaScript files often suffer from slower   page loads, due to the browser requesting each file individually. Many browsers   also are limited to a few simultaneous requests per domain. The wait for a   series of requests and the transfer of unoptimized files can dramatically reduce   the client-side performance of your site. </p>
<p>Here are a handful of Yahoo!\'s best practices that are addressed by the use of ScriptDeploy. </p>
<ul>
  <li><a href="http://developer.yahoo.com/performance/rules.html#num_http" target="_blank" rel="nofollow">Make Fewer HTTP Requests</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#expires" target="_blank" rel="nofollow">Add an Expires or a Cache-Control Header</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#gzip" target="_blank" rel="nofollow">Gzip Components</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#minify" target="_blank" rel="nofollow">Minify JavaScript and CSS</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#etags" target="_blank" rel="nofollow">Configure ETags</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#under25" target="_blank" rel="nofollow">Keep Components under 25K</a></li>
</ul>
<h3><a name="Acknowledgments"></a>Acknowledgments</h3>
<p>Minify was inspired by <a href="http://code.google.com/p/jscsscomp/" target="_blank" rel="nofollow">jscsscomp</a> by Maxim Martynyuk and by the article \'<a href="http://www.hunlock.com/blogs/Supercharged_Javascript" target="_blank" rel="nofollow">Supercharged JavaScript</a>\' by Patrick Hunlock. </p>
<p>The <a href="http://www.crockford.com/javascript/jsmin.html" target="_blank" rel="nofollow">JSMin library</a> used for JavaScript minification was originally   written by Douglas Crockford and was <a href="http://code.google.com/p/jsmin-php" target="_blank" rel="nofollow">ported to PHP</a> by Ryan   Grove specifically for use in Minify. </p>


<h3>Support</h3>
<h4>Screencasts for extra help will fallow--- on the TODO</h4>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module or to file a bug report visit <a href="http://dev.cmsmadesimple.org/projects/ppbm">the CMS Forge</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
</ul>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2009, jeremyBass &lt;<a href="http://corbensproducts.com">corbensproducts.com</a>&gt; All Rights Are Reserved.</p>
<strong>Support more mods like this:</strong><form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="8817675">
<input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form><br/>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
</div ><b class="rbottom"><b class="r4"></b><b class="r3"></b> <b class="r2"></b> <b class="r1"></b></b>

</div>
';
?>

==> ScriptDeploy-0.3.tar: ScriptDeploy/lang/en_US.php <==
<?php


$lang['friendlyname'] = 'Script Deploy';
$lang['postinstall'] = 'The first stop you\'ll want to make is the help';
$lang['postuninstall'] = 'Please feel free to let us know if there is a way to make ScriptDeploy better, <a href="http://help.corbensproducts.com/make-contact.html">Contact us we\'er happy to hear from you.</a>';
$lang['really_uninstall'] = 'Uninstalling this module will not affect any event data and all books to date will still be there. Do you wish to continue?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';

///Admin
$lang['ACToptions'] = 'Account Options';
$lang['manualassignment'] = 'Assignment';

$lang['Script_list'] = 'Scripts';
$lang['Ass_header'] = 'Unified Scripts';
$lang['SampleTag'] = 'Sample Tag';

$lang['prompt_newScript'] = 'Add New Script';
$lang['prompt_newScriptAss'] = 'Add New Script Assignment';
$lang['title_Groups'] = 'Group of Scripts List';
$lang['title_Scripts'] = 'Single Scripts List';
$lang['areyousure'] = 'Important:\n\nIf this is deleted all information will be lost!\n\nIf you have this script in a group you will break the tie and will need to edit the group.\nIt is best to start the deletion process from the Assignment area.';


$lang['smartyHow'] = 'the smarty works like this... Where you\'d have {$smarty.now} you do {{$smarty.now}}  .  Now you can do smarty stuff';




$lang['MediaType']='all : Suitable for all devices.<br/>
aural : Intended for speech synthesizers.<br/>
braille : Intended for braille tactile feedback devices.<br/>
embossed : Intended for paged braille printers.<br/>
handheld : Intended for handheld devices<br/>
print : Intended for paged, opaque material and for documents viewed on screen in print preview mode.<br/>
projection : Intended for projected presentations, for example projectors or print to transparencies.<br/>
screen : Intended primarily for color computer screens.<br/>
tty : Intended for media using a fixed-pitch character grid, such as teletypes and terminals.<br/>
tv : Intended for television-type devices.';



///messages

$lang['Canceled'] = 'You Canceled out of the operation.  Any Work you may have entered has been lost.';

$lang['BtnADDED'] = 'You Just Added a new Script';
$lang['BtnEDITED'] = 'You Just Edited an existing Script';
$lang['BtnDELETED'] = 'You Just Deleted an existing Script';
$lang['type_label'] = 'Type';

$lang['emtpyGroup'] = "You'll need to add a script to the group before calling it";

//Account options
$lang['ScriptSet_label'] = 'Script ID';
$lang['scriptType_label'] = 'Script Type';
$lang['ScriptName_label'] = 'Script Name';
$lang['SingleCode_label'] = 'Default Single Script Call';
$lang['GrouptSize_label'] = 'Total';
$lang['notes_label'] = 'Notes';



$lang['MediaType_label'] = 'MediaType';
$lang['Minify_label'] = 'Pre Minified';
$lang['maxAge_label'] = 'maxAge';
$lang['CreationDate_label'] = 'Creation Date';
$lang['ModifedDate_label'] = 'Modified Date';
$lang['pathOption_label'] = 'Use a path<em>(use "/uploads/...")</em>';
$lang['ScriptIs_label'] = 'Use this script <em>(Note: If a path is set, it will over ride this)</em>';
$lang['debugIT_label'] = 'debugIT';
$lang['debugITnote_label'] = '<em>(Must have Firephp mod)</em>';
$lang['debugT'] = 'Debuging Options';


$lang['noneInType'] = '<h1>You must first add <br/>a script in this type</h1>';


$lang['smartyOn_label'] = '<strong>Process Smarty</strong><br/> data in button fields';
$lang['smartyOn'] = '<h1>Process Smarty data</h1>
<h3>With this turned on you can set the button fields with the values passed by other modules such as Products or Cataloger</h3>';

///Actions
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
//Alerts and Messages
$lang['ClearImg'] = 'Delete Current Image';

$lang['Finish'] = 'Finish';

$lang['cancel'] = 'Cancel';
$lang['form_cancel'] = 'Cancel';

$lang['Save'] = 'Save';

$lang['done'] = 'Done';
$lang['add'] = 'Add';
$lang['submit'] = 'Submit';
$lang['REORDER'] = 'Reorder';

$lang['form_submit'] = 'Save Preferences';

$lang['mod_prefs_title'] = 'Module Preferences';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['optionsupdated'] = 'options updated';





$lang['moddescription'] = 'SPEED YOUR SITE UP !!!! &bull; Output dynamic JS files and CSS WITH smarty... &bull; Set the files to use a subdomain &bull; cached &bull; minified &bull; Did I mention you can use smarty in your JS and CSS script!!!! - Simple, flexible!';
$lang['welcome_text'] = '<p>Hello!</p>';
$lang['changelog'] = '
<ul>

  <li>Version 0.1 Beta release.</li>
  <li>Version 0.2 lots of changes to fix bug...</li>
</ul>';
$lang['help'] = '<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet"/><div class="SimWrap"><b class="rbottom"><b class="r1"></b> <b class="r2"></b><b class="r3"></b> <b class="r4"></b></b>

<div class="Simcon"> <h3 class="BackLink"><a onclick="javascript:window.history.go(-1)" target="_blank" rel="nofollow">&lt;&lt; Back</a></h3>
<h1>What Does This Do?--- this needs updating</h1>
<h2>Write manage and deploy JS and CSS</h2>
<a id="ScriptDeploy"></a>
<p>ScriptDeploy module that can combine multiple CSS or Javascript files, compress their contents (i.e. removal of unnecessary whitespace/comments), and serve the results with HTTP encoding (gzip/deflate) and headers that allow optimal client-side caching. This helps you follow several of Yahoo!\'s <a href="http://developer.yahoo.com/performance/index.html#rules" target="_blank" rel="nofollow">Rules for High Performance Web Sites</a>. (See &quot;Problem Domain&quot; below for more info.) </p>
<h3>The Short of it</h3>
<p>Wirte your scripts, set the order and ScriptDeploy will do the rest!</p>
<table>
  <tbody>
    <tr>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><strong>Before</strong></td>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><img src="http://mrclay.org/wp-content/uploads/2008/09/fiddler_before.png" alt="after" /></td>
    </tr>
    <tr>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><strong>After</strong></td>
      <td style="BORDER-RIGHT: #aaa 1px solid; PADDING-RIGHT: 5px; BORDER-TOP: #aaa 1px solid; PADDING-LEFT: 5px; PADDING-BOTTOM: 5px; BORDER-LEFT: #aaa 1px solid; PADDING-TOP: 5px; BORDER-BOTTOM: #aaa 1px solid"><img src="http://mrclay.org/wp-content/uploads/2008/09/fiddler_after.png" alt="before" /></td>
    </tr>
  </tbody>
</table>



<h2><a id="Features"></a>Features</h2>
<ul>
  <li>Combines and minifies multiple CSS or JavaScript files into a single   download </li>
  <li>Uses an <a href="http://code.google.com/p/minify/source/browse/trunk/min/lib/JSMin.php" target="_blank" rel="nofollow">enhanced port</a> of Douglas Crockford\'s <a href="http://www.crockford.com/javascript/jsmin.html" target="_blank" rel="nofollow">JSMin   library</a> and custom classes to minify <a href="http://code.google.com/p/minify/source/browse/trunk/min/lib/Minify/CSS.php" target="_blank" rel="nofollow">CSS</a> and <a href="http://code.google.com/p/minify/source/browse/trunk/min/lib/Minify/HTML.php" target="_blank" rel="nofollow">HTML</a></li>
  <li>Caches server-side to avoid doing unnecessary work </li>
  <li>Responds with an HTTP 304 (Not Modified) response when the browser has an   up-to-date cache copy ** </li>
  <li>Most modules are lazy-loaded as needed (304 responses use minimal code)  ** </li>
  <li>Automatically rewrites relative URIs in combined CSS files to point to valid locations </li>
  <li>With caching enabled, ScriptDeploy is capable of handling hundreds of requests per second on a moderately powerful server. </li>
  <li>Content-Encoding: gzip, based on request headers. Caching allows it so serve gzipped files faster than Apache\'s mod_deflate option! </li>
</ul>
<h3><em><strong>** Note:</strong> It is best to use a .htaccess script to set the age times. ScriptDeploy is designed for efficiency, but for very high traffic sites, ScriptDeploy may serve files slower than your HTTPd due to the CGI overhead of PHP.  To over come this Just check "use .htaccess in options"</em></h3>
<h2><a name="Requirements"></a>Requirements</h2>
<ul>
  <li>The commonly installed <a href="http://us3.php.net/manual/en/zlib.installation.php" target="_blank" rel="nofollow">zlib   extension</a> is recommended for HTTP encoding functionality. </li>
</ul>
<br/><br/>
<h1>How Do I Use It</h1>


<h3>Get a single script</h3>
use <span class="codeHIGHLIGHT">{cms_module module=ScriptDeploy scriptID="1"} </span> <br/><br/>
<h3>Get a script group</h3>
use <span class="codeHIGHLIGHT">{cms_module module=ScriptDeploy groupID="1"} </span> <br/><br/>
<h2>All output is in the XHTML format, you should work in that.</h2>

<br/><br/>
<h4>Params</h4>
<ul>
<li><strong>scriptID="" </strong><em>(Required/optional)</em> <br/>| set the ID Required only if groupID not called<br/></li>
<li><strong>groupID="" </strong><em>(Required/optional)</em> <br/>| set the ID Required only if scriptID not called<br/></li>
<li><strong>Stype="" </strong><em>(Required/) JS/CSS</em> <br/>| set the ID Required only if scriptID not called<br/></li>




<li><strong>MediaType="" </strong><em>(optional)</em> <br/>| set Media type for CSS files here... overrides db setings.<br/></li>
<li><strong>import="" </strong><em>(optional) true/false</em> <br/>| set the inclusion style for CSS files here... overrides db setings. Ex: true  gives <style type=\"text/css\">@import url("url/cssfile.css") screen;</style><br/></li>

<li><strong>cacheBuster</strong> <em>(optional) <strong>Default:false</strong></em><br/>| This is to instantly uncache an image on the client side after a new uploaded photo is SuperSized... ie: Canyon House.-w150-h0-p0.jpg?1255225007  <font color="red"><strong>( true/false )</strong></font></li>
<li><strong>assign="" </strong><em>(optional)</em> <br/>| Assign the output (return the smarty assignment)  Use in conjunction with out without URL</li>
<li><strong>fsize="" </strong><em>(optional)</em> <br/>| get the size</li>
<li><strong>rootUrl="" </strong><em>(optional)</em> <br/>| ScriptDeploy creates a temp director in the upload folder.  If you move the path to the uplaod to a subdomain you may guide the output with this.</li>
        <ul style="list-style-position:inside;"><li><strong>Exapmle:</strong> you changed <CODE>$config[\'uploads_path\'] = \'/var/www/vhosts/domain.org/httpdocs/uploads\';</CODE> </li>
            <li><strong>to</strong> <CODE>$config[\'uploads_path\'] = \/var/www/vhosts/domain.org/subdomains/media/httpdocs/uploads\';</CODE></li>
            <li>now the uploads url would not work as it would be <u>http://www.domain.org/uploads</u></li>
            <li><strong>So</strong> it can be changed here to <u>http://media.domain.org/uploads</u>  <font color="red"><strong>(NOTE: watch your / )</strong></font></li>
        </ul>
<li><strong>URL="" </strong><em>(optional)</em> <br/>|outputs the url.</li>




		








<!--<li><strong>SandBox=true </strong><em>(optional)</em> <br/>| false<br/></li>

<li><strong>RUNaction="" </strong><em>(optional)</em> <br/>| UDT<br/>| URL <em>(../plugins/function.filename.php)</em><br/>| *More coming Soon*<br/></li>
<li><strong>Lang="" </strong><em>(optional)</em> <br/>| Use Country Codes To dynamicly set the language of the PayPal page<br/></li>-->

</ul>
<br/>

<br/><br/>
<h2><a id="Problem_Domain"></a>Problem Domain</h2>
<p>Pages that refer to multiple CSS or JavaScript files often suffer from slower   page loads, due to the browser requesting each file individually. Many browsers   also are limited to a few simultaneous requests per domain. The wait for a   series of requests and the transfer of unoptimized files can dramatically reduce   the client-side performance of your site. </p>
<p>Here are a handful of Yahoo!\'s best practices that are addressed by the use of ScriptDeploy. </p>
<ul>
  <li><a href="http://developer.yahoo.com/performance/rules.html#num_http" target="_blank" rel="nofollow">Make Fewer HTTP Requests</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#expires" target="_blank" rel="nofollow">Add an Expires or a Cache-Control Header</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#gzip" target="_blank" rel="nofollow">Gzip Components</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#minify" target="_blank" rel="nofollow">Minify JavaScript and CSS</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#etags" target="_blank" rel="nofollow">Configure ETags</a></li>
  <li><a href="http://developer.yahoo.com/performance/rules.html#under25" target="_blank" rel="nofollow">Keep Components under 25K</a></li>
</ul>
<h3><a name="Acknowledgments"></a>Acknowledgments</h3>
<p>Minify was inspired by <a href="http://code.google.com/p/jscsscomp/" target="_blank" rel="nofollow">jscsscomp</a> by Maxim Martynyuk and by the article \'<a href="http://www.hunlock.com/blogs/Supercharged_Javascript" target="_blank" rel="nofollow">Supercharged JavaScript</a>\' by Patrick Hunlock. </p>
<p>The <a href="http://www.crockford.com/javascript/jsmin.html" target="_blank" rel="nofollow">JSMin library</a> used for JavaScript minification was originally   written by Douglas Crockford and was <a href="http://code.google.com/p/jsmin-php" target="_blank" rel="nofollow">ported to PHP</a> by Ryan   Grove specifically for use in Minify. </p>


<h3>Support</h3>
<h4>Screencasts for extra help will fallow--- on the TODO</h4>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module or to file a bug report visit <a href="http://dev.cmsmadesimple.org/projects/ppbm">the CMS Forge</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
</ul>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2009, jeremyBass &lt;<a href="http://corbensproducts.com">corbensproducts.com</a>&gt; All Rights Are Reserved.</p>
<strong>Support more mods like this:</strong><form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="8817675">
<input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form><br/>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
</div ><b class="rbottom"><b class="r4"></b><b class="r3"></b> <b class="r2"></b> <b class="r1"></b></b>

</div>
';
?>
